View source: R/poLCA.predcell.R
| poLCA.predcell | R Documentation |
Calculates the predicted cell percentages from a latent class model, for specified values of the manifest variables.
poLCA.predcell(lc, y)
lc |
A model object estimated using the |
y |
A vector or matrix containing series of responses on the manifest
variables in |
The parameters estimated by a latent class model can be used to produce a
density estimate of the underlying probability mass function across the cells
in the multi-way table of manifest variables. This function calculates cell
percentages for that density estimate, corresponding to selected sets of
responses on the manifest variables, y.
A vector containing cell percentages corresponding to the specified
sets of responses y, based on the estimated latent class model lc.
poLCA
data(carcinoma)
f <- cbind(A, B, C, D, E, F, G) ~ 1
lca3 <- poLCA(f, carcinoma, nclass = 3) # log-likelihood: -293.705
# Only 20 out of 32 possible response patterns are observed
lca3$predcell
# Produce cell probabilities for one sequence of responses
poLCA.predcell(lc = lca3, y = c(1, 1, 1, 1, 1, 1, 1))
# Estimated probabilities for a cell with zero observations
poLCA.predcell(lc = lca3, y = c(1, 1, 1, 1, 1, 1, 2))
# Cell probabilities for both cells at once; y entered as a matrix
poLCA.predcell(lc = lca3, y = rbind(
c(1, 1, 1, 1, 1, 1, 1),
c(1, 1, 1, 1, 1, 1, 2)
))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.