poLCAParallel.goodnessfit: Add predcell, Gsq and Chisq to a fitted poLCA object

View source: R/poLCAParallel.goodnessfit.R

poLCAParallel.goodnessfitR Documentation

Add predcell, Gsq and Chisq to a fitted poLCA object

Description

Finds unique responses and put them in a dataframe along with the observed and expected frequencies. Also calculates the log likelihood ratio and chi squared statistics.

Usage

poLCAParallel.goodnessfit(results)

Arguments

results

A model object estimated using the poLCA function

Details

Wrapper function around the C++ function GoodnessFitRcpp().

Value

The model object with three added items:

  • predcell: dataframe of unique responses with their observed and expected frequencies

  • Gsq: log likelihood ratio

  • Chisq: chi squared statistic


poLCAParallel documentation built on Feb. 20, 2026, 1:09 a.m.