View source: R/poLCAParallel.goodnessfit.R
| poLCAParallel.goodnessfit | R Documentation |
Finds unique responses and put them in a dataframe along with the observed and expected frequencies. Also calculates the log likelihood ratio and chi squared statistics.
poLCAParallel.goodnessfit(results)
results |
A model object estimated using the |
Wrapper function around the C++ function GoodnessFitRcpp().
The model object with three added items:
predcell: dataframe of unique responses with their observed and expected
frequencies
Gsq: log likelihood ratio
Chisq: chi squared statistic
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.