Finds unique responses and put them in a dataframe along with the observed and expected frequencies. Also calculates the log likelihood ratio and chi squared statistics.
poLCAParallel.goodnessfit(results)The model object with three added items:
predcell: dataframe of unique responses with their observed and expected
frequencies
Gsq: log likelihood ratio
Chisq: chi squared statistic
A model object estimated using the poLCA function
Wrapper function around the C++ function GoodnessFitRcpp().