Learn R Programming

poLCAParallel (version 1.2.6)

poLCAParallel.se: Calculates the standard errors and adds them to a fitted poLCA model object

Description

Calculates the standard errors and adds them, as attributes, to a fitted poLCA model object $P.se, $probs.se, $coeff.se and $coeff.V

Usage

poLCAParallel.se(polca, is_smooth = FALSE)

Value

the fitted poLCA model object with the attributes $P.se, $probs.se, $coeff.se and '$coeff.V` modified or added

Arguments

polca

A model object estimated using the poLCA function

is_smooth

Logical, experimental, for calculating the standard errors, whether to smooth the outcome probabilities to produce more numerical stable results at the cost of bias.

Details

R wrapper function for the C++ function StandardErrorRcpp()

$coeff.se and $coeff.V are set to NA if the provided poLCA is a poLCA problem with no regression